@@ -52,6 +52,10 @@
 #endif // __has_feature
 #endif // __has_feature(c_generic_selections)
 
+/* Whether the X11 backend (frame_x11.h) is available.
+   FRAME_X11_BACKEND will be defined if it is and FRAME_NO_X11_BACKEND otherwise. */
+#define FRAME_X11_BACKEND
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -89,6 +93,7 @@ typedef enum UFStatus {
   UFStatusErrorInvalidType, /**< The variable type passed as a void pointer into
                                  a property getter is invalid for the property
                              */
+  UFStatusErrorTouchIdExists, /**< A touch with the same ID already exists */
 } UFStatus;
 
 /** Properties of a device */
@@ -736,6 +741,43 @@ uint64_t frame_touch_get_time(UFTouch touch);
 FRAME_PUBLIC
 uint64_t frame_touch_get_start_time(UFTouch touch);
 
+/**
+ * Accept ownership of a touch
+ *
+ * All touches received should be eventally accepted or rejected.
+ * This decision can come even after they have already ended but
+ * should be done as soon as possible.
+ *
+ * You should accept a touch when you're going to use it and
+ * reject it if you're not interested in it.
+ *
+ * Not all window servers have this concept. Those that do use
+ * this information to pass rejected touches forward to other
+ * clients that might want it.
+ *
+ * @param [in] device The device object for the touch (const)
+ * @param [in] window The window to accept the touch for
+ * @param [in] touch_id The touch ID object for the touch
+ * @return UFStatusSuccess, UFStatusErrorInvalidTouch
+ * @see frame_reject_touch
+ */
+FRAME_PUBLIC
+UFStatus frame_accept_touch(UFDevice device, UFWindowId window,
+                            UFTouchId touch_id);
+
+/**
+ * Reject ownership of a touch
+ *
+ * @param [in] device The device object for the touch (const)
+ * @param [in] window The window to reject the touch for
+ * @param [in] touch_id The touch ID object for the touch
+ * @return UFStatusSuccess, UFStatusErrorInvalidTouch
+ * @see frame_accept_touch
+ */
+FRAME_PUBLIC
+UFStatus frame_reject_touch(UFDevice device, UFWindowId window,
+                            UFTouchId touch_id);
+
 /** @} */
 
 #include "frame_internal.h"
